diff lisp/man.el @ 10642:0e6b71f2ebad

* man.el (Man-default-man-entry): Remove text properties from result.
author Francesco Potortì <pot@gnu.org>
date Fri, 03 Feb 1995 12:07:37 +0000
parents c69ddd9fa3a6
children 9a069c7526b1
line wrap: on
line diff
--- a/lisp/man.el	Fri Feb 03 10:25:44 1995 +0000
+++ b/lisp/man.el	Fri Feb 03 12:07:37 1995 +0000
@@ -3,8 +3,8 @@
 ;; Copyright (C) 1993, 1994 Free Software Foundation, Inc.
 
 ;; Author:		Barry A. Warsaw <bwarsaw@cen.com>
-;; Last-Modified:	$Date: 1994/11/09 12:38:31 $
-;; Version:		$Revision: 1.59 $
+;; Last-Modified:	$Date: 1994/11/22 04:37:43 $
+;; Version:		$Revision: 1.60 $
 ;; Keywords:		help
 ;; Adapted-By:		ESR, pot
 
@@ -480,13 +480,15 @@
 	     (progn (skip-chars-forward "-a-zA-Z0-9_.") (point))))
       
       ;; If looking at something like ioctl(2) or brc(1M), include the
-      ;; section number in the returned value.
-      (concat
-       default-title
-       (if (looking-at
-	    (concat "[ \t]*([ \t]*\\(" Man-section-regexp "\\)[ \t]*)"))
-	   (format "(%s)" (Man-match-substring 1)))
-       ))))
+      ;; section number in the returned value.  Remove text properties.
+      (let ((result (concat
+		     default-title
+		     (if (looking-at
+			  (concat "[ \t]*([ \t]*\\("
+				  Man-section-regexp "\\)[ \t]*)"))
+			 (format "(%s)" (Man-match-substring 1))))))
+	(set-text-properties 0 (length result) nil result)
+	))))
 
 
 ;; ======================================================================